@@ -1,5 +1,5 @@
 /* ====================================================================
- * Copyright (c) 2010-2024 Open Source Applications Foundation.
+ * Copyright (c) 2010-2025 Open Source Applications Foundation.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -297,27 +297,16 @@ static PyObject *t_regexpattern_split(t_regexpattern *self, PyObject *args)
         }
         else
         {
-            class finalizer {
-            public:
-                UnicodeString *array;
-                finalizer(int size) {
-                    array = new UnicodeString[size];
-                }
-                ~finalizer() {
-                    delete[] array;
-                }
-            };
-            finalizer finally(capacity);
+            std::unique_ptr<UnicodeString[]> array(new UnicodeString[capacity]);
             PyObject *tuple;
 
-            if (!finally.array)
+            if (!array.get())
                 return PyErr_NoMemory();
 
-            STATUS_CALL(count = self->object->split(*u, finally.array,
-                                                    capacity, status));
+            STATUS_CALL(count = self->object->split(*u, array.get(), capacity, status));
             tuple = PyTuple_New(count);
             for (int i = 0; i < count; i++)
-                PyTuple_SET_ITEM(tuple, i, PyUnicode_FromUnicodeString(&finally.array[i]));
+                PyTuple_SET_ITEM(tuple, i, PyUnicode_FromUnicodeString(&array[i]));
 
             return tuple;
         }
@@ -797,27 +786,16 @@ static PyObject *t_regexmatcher_split(t_regexmatcher *self, PyObject *args)
         }
         else
         {
-            class finalizer {
-            public:
-                UnicodeString *array;
-                finalizer(int size) {
-                    array = new UnicodeString[size];
-                }
-                ~finalizer() {
-                    delete[] array;
-                }
-            };
-            finalizer finally(capacity);
+            std::unique_ptr<UnicodeString[]> array(new UnicodeString(capacity));
             PyObject *tuple;
 
-            if (!finally.array)
+            if (!array.get())
                 return PyErr_NoMemory();
 
-            STATUS_CALL(count = self->object->split(*u, finally.array,
-                                                    capacity, status));
+            STATUS_CALL(count = self->object->split(*u, array.get(), capacity, status));
             tuple = PyTuple_New(count);
             for (int i = 0; i < count; i++)
-                PyTuple_SET_ITEM(tuple, i, PyUnicode_FromUnicodeString(&finally.array[i]));
+                PyTuple_SET_ITEM(tuple, i, PyUnicode_FromUnicodeString(&array[i]));
 
             return tuple;
         }
